.. _cwvreg_module:

:mod:`cubicweb.cwvreg`
======================

.. automodule:: cubicweb.cwvreg

    .. autoclass:: CWRegistryStore
        :show-inheritance:
        :members:
        :undoc-members:

    .. autoclass:: CWRegistry
        :show-inheritance:
        :members: schema, poss_visible_objects, select

    .. autoclass:: InstancesRegistry
        :show-inheritance:
        :members:

    .. autoclass:: ETypeRegistry
        :show-inheritance:
        :members:

    .. autoclass:: ViewsRegistry
        :show-inheritance:
        :members:

    .. autoclass:: ActionsRegistry
        :show-inheritance:
        :members:

    .. autoclass:: CtxComponentsRegistry
        :show-inheritance:
        :members:

:mod:`logilab.common.registry`
==============================

.. automodule:: logilab.common.registry
